/*
 * JavaScript for Merriam-Webster Dictionary Online
 * 
 * Version: 2.2.3 (Dependent on jQuery v3.3.1)
 * Updated on: June 15, 2018
 * 
 * Copyright © 2017–2018 BLKSerene
 * Licensed under GNU GPLv3
 *
 * This file can be used with the following dictionary:
 * · Merriam-Webster Thesaurus Online
 */

$(document).ready(function() {
  // Detect BlueDict
  try { 
    var blueDict = isBlueDict();
  } catch (e) {
    var blueDict = false
  }

  $('article').each(function() {
    var entry = $(this);
    var contentsMain = entry.children(':not([data-source="supplemental"])');
    var contentsSupplemental = entry.find('span[data-source="supplemental"] > span');
    var contentsAll = contentsMain.add(contentsSupplemental);

    entry.find('.typo7').hide()
    // Create tabs
    if (contentsSupplemental.length > 0 && entry.find('.typo8').length === 0 && entry.find('.tabs').length === 0) {
      contentsSupplemental.hide();
      // Main
      entry.prepend('<div class="tabs"><span class="tab_supplemental">Collegiate</span></div>');
      var tabs = entry.find('.tabs');

      contentsSupplemental.each(function() {
        var tabHeading = $(this).find('.typo7').text();

        // Financial
        if (tabHeading.indexOf('Financial') > -1) {
          tabs.append('<span class="tab_supplemental">Financial</span>');
        // Learner's
        } else if (tabHeading.indexOf('English Language Learners') > -1) {
          tabs.append('<span class="tab_supplemental">Learner\'s</span>');
        // Elementary
        } else if (tabHeading.indexOf('Kids') > -1) {
          tabs.append('<span class="tab_supplemental">Elementary</span>');
        // Medical
        } else if (tabHeading.indexOf('Medical') > -1) {
          tabs.append('<span class="tab_supplemental">Medical</span>');
        // Law
        } else if (tabHeading.indexOf('Law') > -1) {
          tabs.append('<span class="tab_supplemental">Law</span>');
        }
      });

      var tabsSupplemental = entry.find('.tab_supplemental');
      // Intialize tabs
      tabsSupplemental.css('width', 100 / tabsSupplemental.length + '%');
      tabsSupplemental.eq(0).addClass('selected');

      // Main tab
      tabsSupplemental.eq(0).click(function() {
        tabsSupplemental.removeClass('selected');
        $(this).addClass('selected');

        contentsAll.hide();
        contentsMain.show();
      });

      // Other tabs
      contentsSupplemental.each(function(i) {
        var contents = $(this)
        var tabSupplemental = tabsSupplemental.eq(i + 1);

        tabSupplemental.click(function() {
          tabsSupplemental.removeClass('selected');
          $(this).addClass('selected');

          contentsAll.hide();
          contents.parent().show();
          contents.show();
        });
      });
    }

    // Switch to dropdown lists on mobile devices
    if (window.screen.width <= 1080 && tabs.find('.tab_supplemental').length > 3) {
      tabs.addClass('dropdown');
      tabsSupplemental.hide();
      tabsSupplemental.css('width', '100%');
      tabs.prepend('<div class="tab_active">Collegiate</div>');

      var tabActive = tabs.find('.tab_active');
      tabActive.click(function() {
        tabsSupplemental.slideToggle();
        tabs.find('.tab_supplemental.selected').hide();
        setTimeout(function() {
          tabActive.toggleClass('in');
        }, 400);
      });
      tabsSupplemental.click(function() {
        var $this = $(this);
        tabsSupplemental.removeClass('selected');
        $this.addClass('selected');
        tabsSupplemental.slideUp();
        setTimeout(function() {
          tabActive.text($this.text());
          tabActive.toggleClass('in');
        }, 400);
      });
    }
  });

  // Slide arrows
  $('.modules .card-box').each(function() {
    var $this = $(this);

    if ($this.height() > 128) {
      $this.height('128');
      $this.append('<div class="toggle-trigger"><div class="trigger-line"><span class="trigger-arrow"></span></div></div>');
    }

    if ($this.hasClass('small-box')) {
      if ($this.height() < 128) {
        $this.height('128');
      }
    }
  });

  $('.trigger-arrow').off().on('click', function() {
    cardBox = $(this).closest('.card-box');
    
    fullHeight = cardBox[0].scrollHeight + 30;
    if (cardBox.hasClass('open-container')) {
      cardBox.animate({'height': '128px'});
    } else {
      cardBox.animate({'height': fullHeight});
    }
    setTimeout(function() {
      cardBox.toggleClass('open-container');
    }, 400);
  });

  // Anchors
  $('.ety-sl').each(function() {
    var $this = $(this);

    entryID = $this.data('entry-id');
    var href = $this.closest('article').find('.anchor-name[id$="h' + entryID + '-anchor"]').attr('id');
    $this.find('a').attr('href', '#' + href)
  });

  if (blueDict) {
    $('a[href ^= "#"]').each(function() {
      var $this = $(this);
      var href = $this.attr('href');

      hrefBlueDict = href.replace('#', 'entry://#');
      $this.attr('href', hrefBlueDict)
    });
  }

  // Videos
  $('.video-play-link').off().on('click', function(e) {
    var $this = $(this);

    $this.hide();
    $this.next().show();
    
    e.preventDefault();
  });
});
